.. _users-guide-index:

############
User's Guide
############

.. htmlonly::

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 2

    intro.rst
    configuration.rst
    beginner.rst
    developer.rst
    whats_new.rst
    github_stats.rst
    license.rst
    credits.rst




